@@ -1,20 +1,45 @@
-# To compare the result according to the true graph
-compare = function( sim.obj, bdgraph.obj, bdgraph.obj2 = NULL, bdgraph.obj3 = NULL, colnames = NULL, vis = FALSE ) 
+## ------------------------------------------------------------------------------------------------|
+#     Copyright (C) 2012 - 2018  Reza Mohammadi                                                    |
+#                                                                                                  |
+#     This file is part of BDgraph package.                                                        |
+#                                                                                                  |
+#     BDgraph is free software: you can redistribute it and/or modify it under                     |
+#     the terms of the GNU General Public License as published by the Free                         |
+#     Software Foundation; see <https://cran.r-project.org/web/licenses/GPL-3>.                    |
+#                                                                                                  |
+#     Maintainer: Reza Mohammadi <a.mohammadi@uva.nl>                                              |
+## ------------------------------------------------------------------------------------------------|
+#     This function reports below measures to assess the performance of estimated graphs:          |
+## ------------------------------------------------------------------------------------------------|
+# True positive:  number of correctly estimated links.                                             |
+# True negative:  number of true non-existing links which is correctly estimated.                  |
+# False positive: number of links which are not in the true graph, but are incorrectly estimated.  |
+# False negative: number of links which they are in the true graph, but are not estimated.         |
+# F1-score:       weighted average of the positive predictive and true positive rate.              |
+# Specificity:    Specificity value reaches.                                                       |
+# Sensitivity:    Sensitivity value reaches.                                                       |
+# MCC:            Matthews Correlation Coefficients (MCC).                                         |
+## ------------------------------------------------------------------------------------------------|
+
+compare = function( sim.obj, bdgraph.obj, bdgraph.obj2 = NULL, bdgraph.obj3 = NULL, 
+                    colnames = NULL, vis = FALSE ) 
 {
 	if( is.matrix( sim.obj ) )
 	{
-	    if( ( sum( sim.obj == 0 ) + sum( sim.obj == 1 ) ) != ( p ^ 2 ) ) stop( "Element of 'sim.obj' must be zero or one" )
+	    if( ( sum( sim.obj == 0 ) + sum( sim.obj == 1 ) ) != ( p ^ 2 ) ) stop( "Element of 'sim.obj' must be 0 or 1" )
 	    G    = sim.obj
 	}
     
 	if( is.matrix( bdgraph.obj ) )
 	{
-	    if( ( sum( bdgraph.obj == 0 ) + sum( bdgraph.obj == 1 ) ) != ( p ^ 2 ) ) stop( "Element of 'bdgraph.obj' must be zero or one" )
+	    if( ( sum( bdgraph.obj == 0 ) + sum( bdgraph.obj == 1 ) ) != ( p ^ 2 ) ) stop( "Element of 'bdgraph.obj' must be 0 or 1" )
 	    est  = bdgraph.obj
 	}
 	
 	if( !is.matrix( sim.obj )      && ( class( sim.obj )      == "sim"     ) )  G    <- sim.obj $ G 
+
 	if( !is.matrix( bdgraph.obj )  && ( class( bdgraph.obj )  == "bdgraph" ) )  est  <- BDgraph::select( bdgraph.obj ) 
+	if( !is.matrix( bdgraph.obj )  && ( class( bdgraph.obj )  == "ssgraph" ) )  est  <- BDgraph::select( bdgraph.obj ) 
 	if( class( bdgraph.obj )  == "select"  )  est  <- bdgraph.obj $ refit
    
 	G   = as.matrix( G )        # G is the adjacency matrix of true graph 
@@ -33,11 +58,12 @@ compare = function( sim.obj, bdgraph.obj, bdgraph.obj2 = NULL, bdgraph.obj3 = NU
     {
 		if( is.matrix( bdgraph.obj2 ) )
 		{
-		    if( ( sum( bdgraph.obj2 == 0 ) + sum( bdgraph.obj2 == 1 ) ) != ( p ^ 2 ) ) stop( "Element of 'bdgraph.obj2' must be zero or one" )
+		    if( ( sum( bdgraph.obj2 == 0 ) + sum( bdgraph.obj2 == 1 ) ) != ( p ^ 2 ) ) stop( "Element of 'bdgraph.obj2' must be 0 or 1" )
 		    est2 = bdgraph.obj2
 		}
 		
 		if( !is.matrix( bdgraph.obj2 ) && ( class( bdgraph.obj2 ) == "bdgraph" ) )  est2 <- BDgraph::select( bdgraph.obj2 ) 
+		if( !is.matrix( bdgraph.obj2 ) && ( class( bdgraph.obj2 ) == "ssgraph" ) )  est2 <- BDgraph::select( bdgraph.obj2 ) 
 		if( class( bdgraph.obj2 ) == "select"  )  est2 <- bdgraph.obj2 $ refit
 
 		est2 = as.matrix( est2 )
@@ -53,11 +79,12 @@ compare = function( sim.obj, bdgraph.obj, bdgraph.obj2 = NULL, bdgraph.obj3 = NU
     { 
 		if( is.matrix( bdgraph.obj3 ) ) 
 		{
-		    if( ( sum( bdgraph.obj3 == 0 ) + sum( bdgraph.obj3 == 1 ) ) != ( p ^ 2 ) ) stop( "Element of 'bdgraph.obj3' must be zero or one" )
+		    if( ( sum( bdgraph.obj3 == 0 ) + sum( bdgraph.obj3 == 1 ) ) != ( p ^ 2 ) ) stop( "Element of 'bdgraph.obj3' must be 0 or 1" )
 		    est3 = bdgraph.obj3
 		}
 		
 		if( !is.matrix( bdgraph.obj3 ) && ( class( bdgraph.obj3 ) == "bdgraph" ) )  est3 <- BDgraph::select( bdgraph.obj3 ) 
+		if( !is.matrix( bdgraph.obj3 ) && ( class( bdgraph.obj3 ) == "ssgraph" ) )  est3 <- BDgraph::select( bdgraph.obj3 ) 
 		if( class( bdgraph.obj3 ) == "select"  )  est3 <- bdgraph.obj3 $ refit
 		  
 		est3 = as.matrix( est3 ) 
@@ -110,13 +137,15 @@ compare = function( sim.obj, bdgraph.obj, bdgraph.obj2 = NULL, bdgraph.obj3 = NU
 			plot.igraph( est3_igraph, layout = layout.circle, main = colnames[4], vertex.color = "white", vertex.size = sizev, vertex.label.color = 'black' )			
 		}
 		
-		par(op)
+		par( op )
    }
    
 	return( round( result, 3 ) )
 }
     
-# To compare the result
+## ------------------------------------------------------------------------------------------------|
+#    To compare measures the performance of estimated graphs based on true graph
+## ------------------------------------------------------------------------------------------------|
 compute_measures = function( G, est_G ) 
 {
 	upper_G     = G[     upper.tri( G     ) ]
